@@ -1,7 +1,3 @@
-import click
-import pandas as pd
-import sys
-
 from contextlib import nullcontext
 from os import PathLike
 from pathlib import Path
@@ -9,10 +5,20 @@ from tempfile import TemporaryDirectory
 from typing import List, Union
 from zipfile import ZipFile
 
-from .. import imc
-from ... import io
-from ..._cli.utils import OrderedClickGroup
+import click
+import click_log
+import pandas as pd
 
+from ... import io
+from ..._cli.utils import (
+    OrderedClickGroup,
+    SteinbockCLIException,
+    catch_exception,
+    logger,
+)
+from ..._steinbock import SteinbockException
+from ..._steinbock import logger as steinbock_logger
+from .. import imc
 
 imc_cli_available = imc.imc_available
 
@@ -91,6 +97,8 @@ def imc_cmd_group():
     show_default=True,
     help="Path to the panel output file",
 )
+@click_log.simple_verbosity_option(logger=steinbock_logger)
+@catch_exception(handle=SteinbockException)
 def panel_cmd(
     imc_panel_file,
     imc_panel_channel_col,
@@ -119,10 +127,9 @@ def panel_cmd(
         if len(txt_files) > 0:
             panel = imc.create_panel_from_txt_files(txt_files)
     if panel is None:
-        click.echo("ERROR: No panel/.mcd/.txt file found", file=sys.stderr)
-        return
+        raise SteinbockCLIException("No panel/.mcd/.txt file found")
     io.write_panel(panel, panel_file)
-    click.echo(panel_file)
+    logger.info(panel_file)
 
 
 @imc_cmd_group.command(
@@ -181,6 +188,8 @@ def panel_cmd(
     show_default=True,
     help="Path to the image information output file",
 )
+@click_log.simple_verbosity_option(logger=steinbock_logger)
+@catch_exception(handle=SteinbockException)
 def images_cmd(mcd_dir, txt_dir, unzip, panel_file, hpf, img_dir, image_info_file):
     channel_names = None
     if Path(panel_file).exists():
@@ -210,10 +219,9 @@ def images_cmd(mcd_dir, txt_dir, unzip, panel_file, hpf, img_dir, image_info_fil
                 num_dupl += 1
                 first_mcd_txt_file = mcd_txt_files[img_file_stem][0]
                 img_file_stem = f"DUPLICATE{num_dupl:03d}_{img_file_stem}"
-                click.echo(
-                    f"WARNING: File {mcd_txt_file} is a duplicate of "
-                    f"{first_mcd_txt_file}, saving as {img_file_stem}",
-                    file=sys.stderr,
+                logger.warning(
+                    f"File {mcd_txt_file} is a duplicate of {first_mcd_txt_file}, "
+                    f"saving as {img_file_stem}"
                 )
                 mcd_txt_files[img_file_stem].append(mcd_txt_file)
             else:
@@ -246,11 +254,11 @@ def images_cmd(mcd_dir, txt_dir, unzip, panel_file, hpf, img_dir, image_info_fil
                     }
                 )
             image_info_data.append(image_info_row)
-            click.echo(img_file)
+            logger.info(img_file)
             del img
     image_info = pd.DataFrame(data=image_info_data)
     io.write_image_info(image_info, image_info_file)
-    click.echo(image_info_file)
+    logger.info(image_info_file)
 
 
 def _extract_zips(
