@@ -1,13 +1,15 @@
-import click
-import sys
-
 from os import PathLike
 from pathlib import Path
-from skimage import measure
 from typing import List, Sequence, Union
 
+import click
+import click_log
+from skimage import measure
+
+from ..._cli.utils import OrderedClickGroup, catch_exception, logger
+from ..._steinbock import SteinbockException
+from ..._steinbock import logger as steinbock_logger
 from .. import mosaics
-from ..._cli.utils import OrderedClickGroup
 
 
 def _collect_tiff_files(
@@ -50,13 +52,15 @@ def mosaics_cmd_group():
     required=True,
     help="Path to the tile output directory",
 )
+@click_log.simple_verbosity_option(logger=steinbock_logger)
+@catch_exception(handle=SteinbockException)
 def tile_cmd(images, tile_size, mmap, tile_dir):
     img_files = _collect_tiff_files(images)
     Path(tile_dir).mkdir(exist_ok=True)
     for tile_file, tile in mosaics.try_extract_tiles_from_disk_to_disk(
         img_files, tile_dir, tile_size, mmap=mmap
     ):
-        click.echo(tile_file)
+        logger.info(tile_file)
         del tile
 
 
@@ -83,6 +87,8 @@ def tile_cmd(images, tile_size, mmap, tile_dir):
     required=True,
     help="Path to the tile output directory",
 )
+@click_log.simple_verbosity_option(logger=steinbock_logger)
+@catch_exception(handle=SteinbockException)
 def stitch_cmd(tiles, relabel, mmap, img_dir):
     tile_files = _collect_tiff_files(tiles)
     Path(img_dir).mkdir(exist_ok=True)
@@ -91,12 +97,9 @@ def stitch_cmd(tiles, relabel, mmap, img_dir):
     ):
         if relabel:
             if img.ndim != 2:
-                click.echo(
-                    f"WARNING: Failed to relabel image with shape {img.shape}",
-                    file=sys.stderr,
-                )
+                logger.warning(f"Failed to relabel image with shape {img.shape}")
                 continue
             img[:] = measure.label(img)
             img.flush()
-        click.echo(img_file)
+        logger.info(img_file)
         del img
